==> CGAL-6.0-doc_html.tar.xz: doc_html/Surface_mesh_segmentation/index.js <==
var index =
[
    [ "Introduction", "index.html#Surface_mesh_segmentationIntroduction", null ],
    [ "Overview of the Segmentation Process", "index.html#Surface_mesh_segmentationOverviewoftheSegmentation", [
      [ "Shape Diameter Function", "index.html#Surface_mesh_segmentationShapeDiameterFunction", [
        [ "Computing Raw SDF Values", "index.html#Surface_mesh_segmentationRawSDF", null ],
        [ "Post-processing of Raw SDF Values", "index.html#Surface_mesh_segmentationPostprocessing", null ]
      ] ],
      [ "Soft Clustering", "index.html#Surface_mesh_segmentationSoftClustering", null ],
      [ "Hard clustering", "index.html#Surface_mesh_segmentationGraphCut", null ],
      [ "Summary", "index.html#Surface_mesh_segmentationAPI", null ]
    ] ],
    [ "Examples", "index.html#SDFExamples", [
      [ "Example: Computation of SDF Values", "index.html#Example_1", null ],
      [ "Example: Segmentation from SDF Values", "index.html#Example_2", [
        [ "Computation of SDF Values and Segmentation", "index.html#Example_3", null ]
      ] ],
      [ "Using a Polyhedron with an ID per Facet", "index.html#Surface_mesh_segmentationUsingapolyhedron", null ],
      [ "Using a Surface_mesh", "index.html#Surface_mesh_segmentationUsingSM", null ],
      [ "Independent TriangleMesh per Segment", "index.html#Surface_mesh_segmentationIndependentmeshpersegment", null ]
    ] ],
    [ "Performances", "index.html#Performances", null ],
    [ "Design and Implementation History", "index.html#Surface_mesh_segmentationImplementationhistory", null ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Surface_mesh_segmentation/index.js <==
var index =
[
    [ "Introduction", "index.html#Surface_mesh_segmentationIntroduction", null ],
    [ "Overview of the Segmentation Process", "index.html#Surface_mesh_segmentationOverviewoftheSegmentation", [
      [ "Shape Diameter Function", "index.html#Surface_mesh_segmentationShapeDiameterFunction", [
        [ "Computing Raw SDF Values", "index.html#Surface_mesh_segmentationRawSDF", null ],
        [ "Postprocessing of Raw SDF Values", "index.html#Surface_mesh_segmentationPostprocessing", null ]
      ] ],
      [ "Soft Clustering", "index.html#Surface_mesh_segmentationSoftClustering", null ],
      [ "Hard clustering", "index.html#Surface_mesh_segmentationGraphCut", null ],
      [ "Summary", "index.html#Surface_mesh_segmentationAPI", null ]
    ] ],
    [ "Examples", "index.html#SDFExamples", [
      [ "Example: Computation of SDF Values", "index.html#Example_1", null ],
      [ "Example: Segmentation from SDF Values", "index.html#Example_2", [
        [ "Computation of SDF Values and Segmentation", "index.html#Example_3", null ]
      ] ],
      [ "Using a Polyhedron with an ID per Facet", "index.html#Surface_mesh_segmentationUsingapolyhedron", null ],
      [ "Using a Surface_mesh", "index.html#Surface_mesh_segmentationUsingSM", null ],
      [ "Independent TriangleMesh per Segment", "index.html#Surface_mesh_segmentationIndependentmeshpersegment", null ]
    ] ],
    [ "Performances", "index.html#Performances", null ],
    [ "Design and Implementation History", "index.html#Surface_mesh_segmentationImplementationhistory", null ]
];
